/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package org.springblade.modules.shopping.vo;

import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;
import lombok.EqualsAndHashCode;
import org.springblade.modules.finance.entity.OrderGoods;
import org.springblade.modules.shopping.entity.Consign;

import java.util.List;

/**
 * 商品寄售表视图实体类
 *
 * @author BladeX
 * @since 2022-02-13
 */
@Data
@EqualsAndHashCode(callSuper = true)
@ApiModel(value = "ConsignVO对象", description = "商品寄售表")
public class ConsignVO extends Consign {

	private static final long serialVersionUID = 1L;

	@ApiModelProperty(value = "寄售状态")
	private String consignStateDisplayName;

	@ApiModelProperty(value = "寄售来源")
	private String consignForDisplayName;

	@ApiModelProperty(value = "商品编号")
	private String productNo;

	@ApiModelProperty(value = "所有者")
	private String consignUserIdDisplayName;

	@ApiModelProperty(value = "所有者")
	private String consignConfigDisplayName;

	@ApiModelProperty(value = "是否交割")
	private String isDeliveryDisplayName;

	@ApiModelProperty(value = "是否上架")
	private String isSaleDisplayName;

	@ApiModelProperty(value = "是否已预授权，1否，2:是")
	private Integer isGrant;

	@ApiModelProperty(value = "预授权订单号")
	private String orderNo;

	@ApiModelProperty(value = "商品参数")
	private List<GoodsAttributesVO> goodsAttributes;

	@ApiModelProperty(value = "商品规格项值")
	private List<SpecItemsVO> specItems;

	@ApiModelProperty(value = "商品标签")
	private String goodsLabel;

	@ApiModelProperty(value = "商品图片")
	private String goodsImg;

	@ApiModelProperty(value = "商品相册")
	private String gallery;

	@ApiModelProperty(value = "图文详情")
	private String textImg;

	@ApiModelProperty(value = "信誉分可数")
	private Integer scoreCount;

	@ApiModelProperty(value = "可抢订单数")
	private Integer enableCount;

}
